==> v1.7.5.zip: taoler/app/index/lang/zh-cn.php <==
<?php

return [
	//语言
	'language'			=> 'language',
	'chinese'			=> '中文简体',
	'english'			=> 'english',

	//弹窗提示消息
    'add'				=> '添加',
	'delete'			=> '删除',
    'edit'				=> '编辑',
    'uploads'            => '上传',
	'login success'     => '登录成功',
    'login error'     	=> '登录失败',
	'add success'		=> '添加成功!',
	'add error'			=> '添加失败',
	'edit success'		=> '修改成功',
	'edit error'		=> '修改失败',
	'delete success'	=> '删除成功',
	'delete error'		=> '删除失败',
	'upload success'	=> '上传成功',
	'upload error'		=> '上传失败',
	'upgrade success'	=> '升级成功',
	'upgrade error'		=> '升级失败',
	'illegal request'	=> '非法请求',

	//菜单
     'index'			=> 'index',
     'home page'		=> '首页',
	 'user center'		=> '用户中心',
	 'set info'			=> '设置',
	 'my message'		=> '我的消息',
	 'my page'			=> '我的主页',

	 'login'			=> '登录',
	 'logout'			=> '退出',
	 'sign in'			=> '签到',
	 'sign up'			=> '注册',
	 'register'			=> '注册',
	 'discuss'			=> '讨论',
	 'case'				=> '案例',
	 'timeline'			=> '框架日志',

	//帖子
    'poster'			=> '贴主',
    'title'             => '标题',
    'title color'		=> '颜色',
    'add post'			=> '添加帖子',
    'edit post'			=> '编辑帖子',
    'delete post'		=> '删除帖子',
    'post now'			=> '立即发布',
    'my collection'	=> '我的收藏',
    'cancel collection'	=> '取消收藏',
    'all'				=> '综合',
    'finished'			=> '已结',
    'end'				=> '已结',
    'no finished'		=> '未结',
    'hot'				=> '热贴',
    'top'				=> '精贴',
    'cancel hoting'	    => '取消精贴',
    'cancel topping'	=> '取消置顶',
    'go sign'			=> '去签到',
    'more post'		    => '更多帖子',
    'friendly link'	    => '友情链接',
    'reviewers list'	=> '回帖热榜',
	'hot post list'	    => '本周热议',
	'links list'		=> '温馨通道',
	'statement'		    => '说明',
	'trends'			=> '动态',
	'sponsor'			=> '钻级赞助商',
	'i want to join'	=> '我要加入',
	'official products'	=> '官方产品',
	'no comments'		=> '暂时还没有评论',
	'submit comments'	=> '提交评论',
	'reply'			    => '回复',
	'replies'			=> '次回复',
	'accept'			=> '采纳',
	'please input the content' => '请输入内容',
	'ads area'			=> '广告区',
	'enclosure'		    => '附件',
    'add attachment'    => '添加附件',
	'download files'	=> '下载文件',
    'special column'    => '选择专栏',
    'tags'              => '标签',
    'add tags'          => '添加标签',

	 //Sign in/up
	 'username'			=> '用户',
	 'password'			=> '密码',
	 'username or password error' => '用户或密码错误',
	 'new password'		=> '新密码',
	 'reset password'	=> '重置密码',
	 'retrieve password'	=> '找回密码',
	 'email'			=> '邮箱',
	 'confirm password'	=> '确认密码',
	 'captcha'			=> '验证码',
	 'remember password'	=> '一周内记住密码',
	 'forget password'	=> '忘记密码',
	 'login now'		=> '立即登录',
	 'submit'			=> '提交',
	 'go back'			=> '返回',
	 'register now'		=> '立即注册',
	 'mail/username'	=> '邮箱/用户名',
	 '6-16 characters'	=> '6-16 字符',
	 'strong type encryption'	=> '经过强类型加密',
	 'it cannot be changed'	=> '不能更改',
	 'the only way to get back your password'	=> '找回密码唯一途径',
	 'please input the password' => '请输入密码',
	 'please confirm the password' => '请确认密码',
	 'please input the captcha' => '请输入验证码',

	 //user
	 'add friends'		=> '添加为好友',
	 'start a chat'		=> '开始会话',
	 'authentication information'	=> '认证信息',
	 'it is not signed yet'	=> '懒得还没有任何签名',
	 'log in to view'	=> '登录查看',
	 'join'				=> '加入',
	 'recent statements'	=> '最近发帖',
	 'recent answers'	=> '最近回贴',
	 'browses'			=> '浏览',
	 'in' 				=> '在',
	 'accumulate points'	=> '积分',
	 'my post'			=> '我的帖子',
	 'my auth'			=> '我的授权',
	 'Please log in 10 minutes later' => '请10分钟后再登陆',
	 'Login error 3, Please log in 10 minutes later'	=> '连续登陆错误3次,请10分钟后登录',

];

==> v1.7.18.zip: taoler/app/index/lang/zh-cn.php <==
<?php

return [
	//语言
	'language'			=> 'language',
	'chinese'			=> '中文简体',
	'english'			=> 'english',

	//弹窗提示消息
    'add'				=> '添加',
	'delete'			=> '删除',
    'edit'				=> '编辑',
    'uploads'            => '上传',
	'login success'     => '登录成功',
    'login error'     	=> '登录失败',
	'add success'		=> '添加成功!',
	'add error'			=> '添加失败',
	'edit success'		=> '修改成功',
	'edit error'		=> '修改失败',
	'delete success'	=> '删除成功',
	'delete error'		=> '删除失败',
	'upload success'	=> '上传成功',
	'upload error'		=> '上传失败',
	'upgrade success'	=> '升级成功',
	'upgrade error'		=> '升级失败',
	'illegal request'	=> '非法请求',

	//菜单
     'index'			=> 'index',
     'home page'		=> '首页',
	 'user center'		=> '用户中心',
	 'set info'			=> '设置',
	 'my message'		=> '我的消息',
	 'my page'			=> '我的主页',

	 'login'			=> '登录',
	 'logout'			=> '退出',
	 'sign in'			=> '签到',
	 'sign up'			=> '注册',
	 'register'			=> '注册',
	 'discuss'			=> '讨论',
	 'case'				=> '案例',
	 'timeline'			=> '框架日志',

	//帖子
    'poster'			=> '贴主',
    'title'             => '标题',
    'title color'		=> '颜色',
    'add post'			=> '添加帖子',
    'edit post'			=> '编辑帖子',
    'delete post'		=> '删除帖子',
    'post now'			=> '立即发布',
    'my collection'		=> '我的收藏',
	'collection'		=> '收藏',
    'cancel collection'	=> '收藏-',
    'all'				=> '综合',
    'finished'			=> '已结',
    'end'				=> '已结',
    'no finished'		=> '未结',
    'hot'				=> '加精',
    'top'				=> '置顶',
    'cancel hoting'	    => '精-',
    'cancel topping'	=> '顶-',
    'go sign'			=> '去签到',
    'more post'		    => '更多帖子',
    'friendly link'	    => '友情链接',
    'reviewers list'	=> '回帖热榜',
	'hot post list'	    => '本周热议',
	'links list'		=> '温馨通道',
	'statement'		    => '说明',
	'trends'			=> '动态',
	'sponsor'			=> '钻级赞助商',
	'i want to join'	=> '我要加入',
	'official products'	=> '官方产品',
	'no comments'		=> '暂时还没有评论',
	'submit comments'	=> '提交评论',
	'reply'			    => '回复',
	'replies'			=> '次回复',
	'accept'			=> '采纳',
	'please input the content' => '请输入内容',
	'ads area'			=> '广告区',
	'enclosure'		    => '附件',
    'add attachment'    => '添加附件',
	'download files'	=> '下载文件',
    'special column'    => '选择专栏',
    'tags'              => '标签',
    'add tags'          => '添加标签',

	 //Sign in/up
	 'username'			=> '用户',
	 'password'			=> '密码',
	 'username or password error' => '用户或密码错误',
	 'new password'		=> '新密码',
	 'reset password'	=> '重置密码',
	 'retrieve password'	=> '找回密码',
	 'email'			=> '邮箱',
	 'confirm password'	=> '确认密码',
	 'captcha'			=> '验证码',
	 'remember password'	=> '一周内记住密码',
	 'forget password'	=> '忘记密码',
	 'login now'		=> '立即登录',
	 'submit'			=> '提交',
	 'go back'			=> '返回',
	 'register now'		=> '立即注册',
	 'mail/username'	=> '邮箱/用户名',
	 '6-16 characters'	=> '6-16 字符',
	 'strong type encryption'	=> '经过强类型加密',
	 'it cannot be changed'	=> '不能更改',
	 'the only way to get back your password'	=> '找回密码唯一途径',
	 'please input the password' => '请输入密码',
	 'please confirm the password' => '请确认密码',
	 'please input the captcha' => '请输入验证码',

	 //user
	 'add friends'		=> '添加为好友',
	 'start a chat'		=> '开始会话',
	 'authentication information'	=> '认证信息',
	 'it is not signed yet'	=> '懒得还没有任何签名',
	 'log in to view'	=> '登录查看',
	 'join'				=> '加入',
	 'recent statements'	=> '最近发帖',
	 'recent answers'	=> '最近回贴',
	 'browses'			=> '浏览',
	 'in' 				=> '在',
	 'accumulate points'	=> '积分',
	 'my post'			=> '我的帖子',
	 'my auth'			=> '我的授权',
	 'Please log in 10 minutes later' => '请10分钟后再登陆',
	 'Login error 3, Please log in 10 minutes later'	=> '连续登陆错误3次,请10分钟后登录',
	 'Account disabled'	=> '账号被禁用，请联系管理员',
	 'Pending approval'	=> '待审核，请联系管理员',

];
